<?php
/**
 * CommonPlugin for phplist.
 *
 * This file is a part of CommonPlugin.
 *
 * @category  phplist
 *
 * @author    Duncan Cameron
 * @copyright 2011-2018 Duncan Cameron
 * @license   http://www.gnu.org/licenses/gpl.html GNU General Public License, Version 3
 */

/**
 * This file contains the Spanish translations.
 */
return [
//  CommonPlugin.php
    ['phpinfo', 'phpinfo'],
    ['config.php', 'config.php'],
    ['php session', 'php session'],
//  Pager.php
    ['Showing %d to %d of %d', 'Mostrando %d al %d de %d'],
    ['no_results', 'No hay resultados para mostrar'],
//  Toolbar.php
    ['help', 'ayuda'],
//  Widget.php
    ['Select attributes', 'Select attributes'],
//  General
    ['top', 'arriba'],
//  widget_attributeform.tpl.php
    ['Search for', 'Buscar'],
    ['All', 'All'],
    ['confirmed only', 'confirmed only'],
    ['unconfirmed only', 'unconfirmed only'],
    ['blacklisted only', 'blacklisted only'],
    ['not blacklisted only', 'not blacklisted only'],
//  ExportCSVAsync.php
    ['Exporting, this may take a while', 'Exporting, this may take a while'],
    ['Generating the export data', 'Generating the export data'],
    ['Exported %d of %d %d%%', 'Exported %d of %d %d%%'],
];
